@@ -3,7 +3,7 @@ package Async::Event::Interval;
 use warnings;
 use strict;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Parallel::ForkManager;
 
@@ -11,41 +11,37 @@ sub new {
     my $self = bless {}, shift;
     $self->{pm} = Parallel::ForkManager->new(1);
     $self->_set(@_);
+    $self->{started} = 0;
     return $self;
 }
 sub start {
     my $self = shift;
-    if ($self->{stop}){
+    if ($self->{started}){
         warn "event already running...\n";
         return;
     }
+    $self->{started} = 1;
     $self->_event;
 }
-sub restart {
-    my $self = shift;
-    if ($self->{stop}){
-        warn "event already running...\n";
-        return;
-    }
-    $self->_event(
-        $self->{interval},
-        $self->{cb},
-        @{ $self->{args} },
-    );
-}
+*restart = \&start;
 sub stop {
     my $self = shift;
     kill 9, $self->{pid};
+    $self->{started} = 0;
     $self->{stop} = 1;
 }
+sub status {
+    my $self = shift;
+    return $self->{started};
+}
 sub _event {
     my $self = shift;
 
     for (0..1){
         my $pid = $self->{pm}->start;
         if ($pid){
-           $self->_pid($pid);
-           last;
+            $self->_pid($pid);
+            last;
         }
         while(1){
             $self->{cb}->(@{ $self->{args} });
@@ -68,6 +64,7 @@ sub _set {
 sub DESTROY {
     $_[0]->stop;
 }
+sub _vim{}
 1;
 
 __END__
@@ -98,8 +95,9 @@ an event that can share data with the main application, see L</EXAMPLES>.
         print "$_: in main loop\n";
 
         $event->stop if $_ == 3;
-        $event->restart if $_ == 7;
+        $event->start if $_ == 7;
 
+        print "event is running: " . $event->status . "\n";
         sleep 1;
     }
 
@@ -149,7 +147,11 @@ Stops the event from being executed.
 
 =head2 restart
 
-Resumes execution of a stopped event.
+Alias for C<start()>. Re-starts a C<stop()>ped event.
+
+=head2 status
+
+Return C<0> (false) if the event is not running, and C<1> (true) if it is.
 
 =head1 EXAMPLES
 
